//-f

#version 3.7;

global_settings {
   assumed_gamma 2.2
   charset utf8
   max_trace_level 20
} //global_settings

#include "colors.inc"
#include "BorderChars_Definitions.inc"
#include "BorderChars_Styles.inc"

#local CameraX = 0;
#local CameraY = 0;
#local CameraZ = 1.75;

camera {
   orthographic
   location <CameraX, CameraY, -CameraZ>
   direction <0, 0, 1>
   look_at <CameraX, CameraY, 0>
} //camera

#declare TextColor_Outer = texture {pigment {color White} finish {emission 1}}

#declare TextColor_Inner = texture {
   #declare Color0 = color <0, 216, 183> / 255 * 1.05; //Bottom
   #declare Color1 = color <154, 3, 200> / 255 * 1.05; //Top
   pigment {
      gradient y
      color_map {
         [0 color Color0]
         [.4 color (Color0 * 75 + Color1 * 25) / 100]
         [.6 (Color0 + Color1) / 2]
         [1 color Color1]
      } //color_map
   } //pigment
   finish {emission 1}
   #local YScaleAdd_Bottom = .75 / 2 * .95; //Height of the bottom of the "g"
   #local YScaleAdd_Top = .075; //Height of the top of the "*"
   scale <1, 1 + YScaleAdd_Bottom + YScaleAdd_Top, 1>
   translate -YScaleAdd_Bottom * y
} //texture

#declare TextColor_Back = texture {pigment {color White}}

#macro ComputeKerningValue (CharIndex_Left, CharIndex_Right, NSteps)

   #debug concat ("\nComputing kerning value for indexes ", str (CharIndex_Left, 0, 0), ", ", str (CharIndex_Right, 0, 0), "\n")

   #local CharY0 = -.35625; //Lowest y value of any character
   #local CharY1 = 1.075; //Highest y value of any character

   #local SegmentHeight = (CharY1 - CharY0) / NSteps;

   #local TChar_Left = object {
      union {
         object {BorderCharacter [CharIndex_Left]}
         box {<-1, CharY0, -.1> <0, CharY1, 0> texture {TextColor_Outer}}
      } //union
   } //object

   #local TChar_Right = object {
      union {
         object {BorderCharacter [CharIndex_Right]}
         box {<BorderCharacterWidth [CharIndex_Right], CharY0, -.1> <BorderCharacterWidth [CharIndex_Right] + 1, CharY1, 0> texture {TextColor_Outer}}
      } //union
   } //object

   #local MinDistance = 1000;

   #for (I, 0, NSteps - 1)
      #local SegmentY0 = CharY0 + I * SegmentHeight;
      #local SegmentY1 = SegmentY0 + SegmentHeight;
      #local Segment_Left = object {
         intersection {
            object {TChar_Left}
            plane {y, SegmentY0 inverse texture {TextColor_Outer}}
            plane {y, SegmentY1 texture {TextColor_Outer}}
         } //intersection
      } //object
      #local Segment_Right = object {
         intersection {
            object {TChar_Right}
            plane {y, SegmentY0 inverse texture {TextColor_Outer}}
            plane {y, SegmentY1 texture {TextColor_Outer}}
         } //intersection
      } //object
      #local SegmentWidth_Left = max_extent (Segment_Left); //POV-RAY DOES NOT COMPUTE THIS CORRECTLY.
      #local SegmentWidth_Right = min_extent (Segment_Right); //POV-RAY DOES NOT COMPUTE THIS CORRECTLY.
      #local X1 = SegmentWidth_Left.x;
      #local X2 = BorderCharacterWidth [CharIndex_Left] + SegmentWidth_Right.x;
      #local CurDistance = X2 - X1;
      #if (CurDistance < MinDistance)
         #local MinDistance = CurDistance;
      #end //#if
   #end //#for

   (-MinDistance)

#end //#macro ComputeKerningValue

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* *                                                                                                                 * */
/* *                                                                                                                 * */
/* * THE SCENE                                                                                                       * */
/* *                                                                                                                 * */
/* *                                                                                                                 * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

#declare TextScale = 1;

#local Style = 2;
#local InvisibleBorderWidth = 0;
#local TextDepth = .0002;
#local BorderWidth = .025;
#local BorderDepth = .0001;

Stylize (Style, TextDepth, InvisibleBorderWidth, BorderWidth, BorderDepth, -999, -999, -999)

#local LeftMargin = -1;
#local TopMargin = -.5;

#local NSteps = 1000; //More steps equals more accuracy.

#local CharIndex_Left = 0;
#local CharIndex_Right = 1;

#declare Kerning [CharIndex_Left] [CharIndex_Right] = ComputeKerningValue (CharIndex_Left, CharIndex_Right, NSteps);

object {BorderCharacter [CharIndex_Left] translate <LeftMargin, TopMargin, 0>}
object {BorderCharacter [CharIndex_Right] translate <LeftMargin + BorderCharacterWidth [CharIndex_Left] + Kerning [CharIndex_Left] [CharIndex_Right], TopMargin, 0>}
